@@ -825,6 +825,9 @@ func (s *contentNodeShifter) Insert(old, new contentNodeI) contentNodeI {
 			panic(fmt.Sprintf("unknown type %T", new))
 		}
 		if vv.s.languagei == newp.s.languagei {
+			if newp != old {
+				resource.MarkStale(old)
+			}
 			return new
 		}
 		is := make(contentNodeIs, s.numLanguages)
@@ -836,7 +839,10 @@ func (s *contentNodeShifter) Insert(old, new contentNodeI) contentNodeI {
 		if !ok {
 			panic(fmt.Sprintf("unknown type %T", new))
 		}
-		resource.MarkStale(vv[newp.s.languagei])
+		oldp := vv[newp.s.languagei]
+		if oldp != newp {
+			resource.MarkStale(oldp)
+		}
 		vv[newp.s.languagei] = new
 		return vv
 	case *resourceSource:
@@ -845,6 +851,9 @@ func (s *contentNodeShifter) Insert(old, new contentNodeI) contentNodeI {
 			panic(fmt.Sprintf("unknown type %T", new))
 		}
 		if vv.LangIndex() == newp.LangIndex() {
+			if vv != newp {
+				resource.MarkStale(vv)
+			}
 			return new
 		}
 		rs := make(resourceSources, s.numLanguages)
@@ -856,7 +865,10 @@ func (s *contentNodeShifter) Insert(old, new contentNodeI) contentNodeI {
 		if !ok {
 			panic(fmt.Sprintf("unknown type %T", new))
 		}
-		resource.MarkStale(vv[newp.LangIndex()])
+		oldp := vv[newp.LangIndex()]
+		if oldp != newp {
+			resource.MarkStale(oldp)
+		}
 		vv[newp.LangIndex()] = newp
 		return vv
 	default:
@@ -1054,7 +1066,7 @@ func (h *HugoSites) resolveAndClearStateForIdentities(
 	)
 
 	for _, id := range changes {
-		if staler, ok := id.(resource.Staler); ok && !staler.IsStale() {
+		if staler, ok := id.(resource.Staler); ok {
 			var msgDetail string
 			if p, ok := id.(*pageState); ok && p.File() != nil {
 				msgDetail = fmt.Sprintf(" (%s)", p.File().Filename())
@@ -1084,7 +1096,7 @@ func (h *HugoSites) resolveAndClearStateForIdentities(
 				return b
 			}
 
-			h.MemCache.ClearMatching(shouldDelete)
+			h.MemCache.ClearMatching(nil, shouldDelete)
 
 			return ll, nil
 		}); err != nil {
